Slot: definition_uri - LinkML Model

# Slot: definition_uri

the "native" URI of the element

URI: linkml:definition_uri

## Domain and Range

Element → 0..1 Uriorcurie

## Parents

## Children

## Used by

- ClassDefinition
- Definition
- Element
- EnumDefinition
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Comments: |  | Formed by combining the default_prefix with the mangled element